==> fet-5.14.2.tar.bz2: fet-5.14.2/src/interface/modifyconstraintactivitiespreferredstartingtimesform.h <==
/***************************************************************************
                          modifyconstraintactivitiespreferredstartingtimesform.h  -  description
                             -------------------
    begin                : 11 Feb 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTACTIVITIESPREFERREDSTARTINGTIMESFORM_H
#define MODIFYCONSTRAINTACTIVITIESPREFERREDSTARTINGTIMESFORM_H

#include "ui_modifyconstraintactivitiespreferredstartingtimesform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ModifyConstraintActivitiesPreferredStartingTimesForm : public QDialog, Ui::ModifyConstraintActivitiesPreferredStartingTimesForm_template  {
	Q_OBJECT

public:
	ConstraintActivitiesPreferredStartingTimes* _ctr;

	ModifyConstraintActivitiesPreferredStartingTimesForm(ConstraintActivitiesPreferredStartingTimes* ctr);
	~ModifyConstraintActivitiesPreferredStartingTimesForm();

	void updateTeachersComboBox();
	void updateStudentsComboBox();
	void updateSubjectsComboBox();
	void updateActivityTagsComboBox();

	void colorItem(QTableWidgetItem* item);

public slots:
	void ok();
	void cancel();
	
	void itemClicked(QTableWidgetItem* item);
	void horizontalHeaderClicked(int col);
	void verticalHeaderClicked(int row);
	
	void setAllSlotsAllowed();
	void setAllSlotsNotAllowed();
};

#endif

==> fet-5.25.0.tar.bz2: fet-5.25.0/src/interface/modifyconstraintactivitiespreferredstartingtimesform.h <==
/***************************************************************************
                          modifyconstraintactivitiespreferredstartingtimesform.h  -  description
                             -------------------
    begin                : 11 Feb 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTACTIVITIESPREFERREDSTARTINGTIMESFORM_H
#define MODIFYCONSTRAINTACTIVITIESPREFERREDSTARTINGTIMESFORM_H

#include "ui_modifyconstraintactivitiespreferredstartingtimesform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ModifyConstraintActivitiesPreferredStartingTimesForm : public QDialog, Ui::ModifyConstraintActivitiesPreferredStartingTimesForm_template  {
	Q_OBJECT

public:
	ConstraintActivitiesPreferredStartingTimes* _ctr;

	ModifyConstraintActivitiesPreferredStartingTimesForm(QWidget* parent, ConstraintActivitiesPreferredStartingTimes* ctr);
	~ModifyConstraintActivitiesPreferredStartingTimesForm();

	void updateTeachersComboBox();
	void updateStudentsComboBox(QWidget* parent);
	void updateSubjectsComboBox();
	void updateActivityTagsComboBox();

	void colorItem(QTableWidgetItem* item);

public slots:
	void ok();
	void cancel();
	
	void itemClicked(QTableWidgetItem* item);
	void horizontalHeaderClicked(int col);
	void verticalHeaderClicked(int row);
	
	void setAllSlotsAllowed();
	void setAllSlotsNotAllowed();
};

#endif
